bayespy.inference.vmp.nodes.gaussian.GaussianMoments.add_converter
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianMoments.add_converter